@@ -1310,6 +1310,7 @@ ditem_execute (const GnomeDesktopItem *item,
 	       char *appargv[],
 	       GList *file_list,
 	       gboolean launch_only_one,
+	       gboolean use_current_dir,
 	       GError **error)
 {
         char **real_argv;
@@ -1319,9 +1320,13 @@ ditem_execute (const GnomeDesktopItem *item,
 	GSList *vector_list;
 	GSList *args, *arg_ptr;
 	int added_status;
+	const char *working_dir;
 
         g_return_val_if_fail (item, -1);
 
+	if ( ! use_current_dir)
+		working_dir = g_get_home_dir ();
+
 	if (gnome_desktop_item_get_boolean (item, GNOME_DESKTOP_ITEM_TERMINAL)) {
 		const char *options =
 			gnome_desktop_item_get_string (item, GNOME_DESKTOP_ITEM_TERMINAL_OPTIONS);
@@ -1362,7 +1367,7 @@ ditem_execute (const GnomeDesktopItem *item,
 		g_slist_foreach (vector_list, (GFunc)g_free, NULL);
 		g_slist_free (vector_list);
 
-		if ( ! g_spawn_async (NULL /* working_directory */,
+		if ( ! g_spawn_async (working_dir,
 				      real_argv,
 				      NULL /* envp */,
 				      G_SPAWN_SEARCH_PATH /* flags */,
@@ -1514,6 +1519,7 @@ gnome_desktop_item_launch (const GnomeDesktopItem *item,
 
 	ret = ditem_execute (item, temp_argc, temp_argv, file_list,
 			     (flags & GNOME_DESKTOP_ITEM_LAUNCH_ONLY_ONE),
+			     (flags & GNOME_DESKTOP_ITEM_LAUNCH_USE_CURRENT_DIR),
 			     error);
 
 	g_strfreev (temp_argv);
@@ -1560,6 +1566,26 @@ gnome_desktop_item_drop_uri_list (const GnomeDesktopItem *item,
 	return ret;
 }
 
+static gboolean
+exec_exists (const char *exec)
+{
+	if (g_path_is_absolute (exec)) {
+		if (access (exec, X_OK) == 0)
+			return TRUE;
+		else
+			return FALSE;
+	} else {
+                char *tryme;
+
+		tryme = g_find_program_in_path (exec);
+		if (tryme != NULL) {
+			g_free (tryme);
+			return TRUE;
+		}
+		return FALSE;
+	}
+}
+
 /**
  * gnome_desktop_item_exists:
  * @item: A desktop item
@@ -1581,17 +1607,9 @@ gnome_desktop_item_exists (const GnomeDesktopItem *item)
 
 	try_exec = lookup (item, GNOME_DESKTOP_ITEM_TRY_EXEC);
 
-	if (try_exec != NULL) {
-                char *tryme;
-
-		tryme = g_find_program_in_path (try_exec);
-		if (tryme != NULL) {
-			g_free (tryme);
-			/* We will try the application itself
-			 * next if applicable */
-		} else {
-			return FALSE;
-		}
+	if (try_exec != NULL &&
+	    ! exec_exists (try_exec)) {
+		return FALSE;
 	}
 
 	if (item->type == GNOME_DESKTOP_ITEM_TYPE_APPLICATION) {
@@ -1613,21 +1631,10 @@ gnome_desktop_item_exists (const GnomeDesktopItem *item)
 
 		exe = argv[0];
 
-		if (g_path_is_absolute (exe) &&
-		    access (argv[0], X_OK) != 0) {
+		if ( ! exec_exists (exe)) {
 			g_strfreev (argv);
 			return FALSE;
 		}
-
-		if ( ! g_path_is_absolute (exe)) {
-			char *tryme = g_find_program_in_path (exe);
-			if (tryme == NULL) {
-				g_strfreev (argv);
-				return FALSE;
-			}
-			g_free (tryme);
-		}
-
 		g_strfreev (argv);
 	}
 
@@ -1924,7 +1931,7 @@ gnome_desktop_item_find_icon (const char *icon,
 			      int desired_size,
 			      int flags)
 {
-	if (icon == NULL) {
+	if (icon == NULL || strcmp(icon,"") == 0) {
 		return NULL;
 	} else if (g_path_is_absolute (icon)) {
 		if (g_file_test (icon, G_FILE_TEST_EXISTS)) {
@@ -3255,6 +3262,16 @@ ditem_save (GnomeDesktopItem *item, const char *uri, GError **error)
 			return FALSE;
 		}
 	}
+	if (result != GNOME_VFS_OK) {
+		g_set_error (error,
+			     /* FIXME: better errors */
+			     GNOME_DESKTOP_ITEM_ERROR,
+			     GNOME_DESKTOP_ITEM_ERROR_CANNOT_OPEN,
+			     _("Error writing file '%s': %s"),
+			     uri, strerror (errno));
+
+		return FALSE;
+	}
 
 	vfs_printf (handle, "[Desktop Entry]\n");
 	for (li = item->keys; li != NULL; li = li->next) {
@@ -3319,7 +3336,7 @@ gnome_desktop_item_error_quark (void)
 {
 	static GQuark q = 0;
 	if (q == 0)
-		q = g_quark_from_static_string ("g-file-error-quark");
+		q = g_quark_from_static_string ("gnome-desktop-item-error-quark");
 
 	return q;
 }
